@@ -7,51 +7,58 @@ use std::sync::Arc;
 use dashmap::mapref::entry::Entry;
 use smol_str::SmolStr;
 
-use crate::db::{HasJar, QueryResult, SemanticDb, SemanticJar};
+use crate::db::{QueryResult, SemanticDb, SemanticJar};
 use crate::files::FileId;
-use crate::symbols::Dependency;
+use crate::semantic::Dependency;
 use crate::FxDashMap;
 
-/// ID uniquely identifying a module.
+/// Representation of a Python module.
+///
+/// The inner type wrapped by this struct is a unique identifier for the module
+/// that is used by the struct's methods to lazily query information about the module.
 #[derive(Copy, Clone, Debug, Eq, PartialEq, Hash)]
 pub struct Module(u32);
 
 impl Module {
-    pub fn name<Db>(&self, db: &Db) -> QueryResult<ModuleName>
-    where
-        Db: HasJar<SemanticJar>,
-    {
-        let modules = &db.jar()?.module_resolver;
+    /// Return the absolute name of the module (e.g. `foo.bar`)
+    pub fn name(&self, db: &dyn SemanticDb) -> QueryResult<ModuleName> {
+        let jar: &SemanticJar = db.jar()?;
+        let modules = &jar.module_resolver;
 
         Ok(modules.modules.get(self).unwrap().name.clone())
     }
 
-    pub fn path<Db>(&self, db: &Db) -> QueryResult<ModulePath>
-    where
-        Db: HasJar<SemanticJar>,
-    {
-        let modules = &db.jar()?.module_resolver;
+    /// Return the path to the source code that defines this module
+    pub fn path(&self, db: &dyn SemanticDb) -> QueryResult<ModulePath> {
+        let jar: &SemanticJar = db.jar()?;
+        let modules = &jar.module_resolver;
 
         Ok(modules.modules.get(self).unwrap().path.clone())
     }
 
-    pub fn kind<Db>(&self, db: &Db) -> QueryResult<ModuleKind>
-    where
-        Db: HasJar<SemanticJar>,
-    {
-        let modules = &db.jar()?.module_resolver;
+    /// Determine whether this module is a single-file module or a package
+    pub fn kind(&self, db: &dyn SemanticDb) -> QueryResult<ModuleKind> {
+        let jar: &SemanticJar = db.jar()?;
+        let modules = &jar.module_resolver;
 
         Ok(modules.modules.get(self).unwrap().kind)
     }
 
-    pub fn resolve_dependency<Db>(
+    /// Attempt to resolve a dependency of this module to an absolute [`ModuleName`].
+    ///
+    /// A dependency could be either absolute (e.g. the `foo` dependency implied by `from foo import bar`)
+    /// or relative to this module (e.g. the `.foo` dependency implied by `from .foo import bar`)
+    ///
+    /// - Returns an error if the query failed.
+    /// - Returns `Ok(None)` if the query succeeded,
+    ///   but the dependency refers to a module that does not exist.
+    /// - Returns `Ok(Some(ModuleName))` if the query succeeded,
+    ///   and the dependency refers to a module that exists.
+    pub fn resolve_dependency(
         &self,
-        db: &Db,
+        db: &dyn SemanticDb,
         dependency: &Dependency,
-    ) -> QueryResult<Option<ModuleName>>
-    where
-        Db: HasJar<SemanticJar>,
-    {
+    ) -> QueryResult<Option<ModuleName>> {
         let (level, module) = match dependency {
             Dependency::Module(module) => return Ok(Some(module.clone())),
             Dependency::Relative { level, module } => (*level, module.as_deref()),
@@ -96,7 +103,8 @@ impl Module {
 
 /// A module name, e.g. `foo.bar`.
 ///
-/// Always normalized to the absolute form (never a relative module name).
+/// Always normalized to the absolute form
+/// (never a relative module name, i.e., never `.foo`).
 #[derive(Clone, Debug, Eq, PartialEq, Hash)]
 pub struct ModuleName(smol_str::SmolStr);
 
@@ -133,10 +141,13 @@ impl ModuleName {
         Some(Self(name))
     }
 
+    /// An iterator over the components of the module name:
+    /// `foo.bar.baz` -> `foo`, `bar`, `baz`
     pub fn components(&self) -> impl DoubleEndedIterator<Item = &str> {
         self.0.split('.')
     }
 
+    /// The name of this module's immediate parent, if it has a parent
     pub fn parent(&self) -> Option<ModuleName> {
         let (_, parent) = self.0.rsplit_once('.')?;
 
@@ -168,9 +179,10 @@ impl std::fmt::Display for ModuleName {
 
 #[derive(Copy, Clone, Debug, Eq, PartialEq, Hash)]
 pub enum ModuleKind {
+    /// A single-file module (e.g. `foo.py` or `foo.pyi`)
     Module,
 
-    /// A python package (a `__init__.py` or `__init__.pyi` file)
+    /// A python package (`foo/__init__.py` or `foo/__init__.pyi`)
     Package,
 }
 
@@ -190,10 +202,12 @@ impl ModuleSearchPath {
         }
     }
 
+    /// Determine whether this is a first-party, third-party or standard-library search path
     pub fn kind(&self) -> ModuleSearchPathKind {
         self.inner.kind
     }
 
+    /// Return the location of the search path on the file system
     pub fn path(&self) -> &Path {
         &self.inner.path
     }
@@ -240,16 +254,15 @@ pub struct ModuleData {
 // Queries
 //////////////////////////////////////////////////////
 
-/// Resolves a module name to a module id
-/// TODO: This would not work with Salsa because `ModuleName` isn't an ingredient and, therefore, cannot be used as part of a query.
-///  For this to work with salsa, it would be necessary to intern all `ModuleName`s.
+/// Resolves a module name to a module.
+///
+/// TODO: This would not work with Salsa because `ModuleName` isn't an ingredient
+/// and, therefore, cannot be used as part of a query.
+/// For this to work with salsa, it would be necessary to intern all `ModuleName`s.
 #[tracing::instrument(level = "debug", skip(db))]
-pub fn resolve_module<Db>(db: &Db, name: ModuleName) -> QueryResult<Option<Module>>
-where
-    Db: SemanticDb + HasJar<SemanticJar>,
-{
-    let jar = db.jar();
-    let modules = &jar?.module_resolver;
+pub fn resolve_module(db: &dyn SemanticDb, name: ModuleName) -> QueryResult<Option<Module>> {
+    let jar: &SemanticJar = db.jar()?;
+    let modules = &jar.module_resolver;
 
     let entry = modules.by_name.entry(name.clone());
 
@@ -267,7 +280,7 @@ where
             let file_id = db.file_id(&normalized);
             let path = ModulePath::new(root_path.clone(), file_id);
 
-            let id = Module(
+            let module = Module(
                 modules
                     .next_module_id
                     .fetch_add(1, std::sync::atomic::Ordering::Relaxed),
@@ -275,7 +288,7 @@ where
 
             modules
                 .modules
-                .insert(id, Arc::from(ModuleData { name, path, kind }));
+                .insert(module, Arc::from(ModuleData { name, path, kind }));
 
             // A path can map to multiple modules because of symlinks:
             // ```
@@ -284,42 +297,36 @@ where
             // ```
             // Here, both `foo` and `bar` resolve to the same module but through different paths.
             // That's why we need to insert the absolute path and not the normalized path here.
-            let absolute_id = if absolute_path == normalized {
+            let absolute_file_id = if absolute_path == normalized {
                 file_id
             } else {
                 db.file_id(&absolute_path)
             };
 
-            modules.by_file.insert(absolute_id, id);
+            modules.by_file.insert(absolute_file_id, module);
 
-            entry.insert_entry(id);
+            entry.insert_entry(module);
 
-            Ok(Some(id))
+            Ok(Some(module))
         }
     }
 }
 
-/// Resolves the module id for the given path.
+/// Resolves the module for the given path.
 ///
-/// Returns `None` if the path is not a module in `sys.path`.
+/// Returns `None` if the path is not a module locatable via `sys.path`.
 #[tracing::instrument(level = "debug", skip(db))]
-pub fn path_to_module<Db>(db: &Db, path: &Path) -> QueryResult<Option<Module>>
-where
-    Db: SemanticDb + HasJar<SemanticJar>,
-{
+pub fn path_to_module(db: &dyn SemanticDb, path: &Path) -> QueryResult<Option<Module>> {
     let file = db.file_id(path);
     file_to_module(db, file)
 }
 
-/// Resolves the module id for the file with the given id.
+/// Resolves the module for the file with the given id.
 ///
-/// Returns `None` if the file is not a module in `sys.path`.
+/// Returns `None` if the file is not a module locatable via `sys.path`.
 #[tracing::instrument(level = "debug", skip(db))]
-pub fn file_to_module<Db>(db: &Db, file: FileId) -> QueryResult<Option<Module>>
-where
-    Db: SemanticDb + HasJar<SemanticJar>,
-{
-    let jar = db.jar()?;
+pub fn file_to_module(db: &dyn SemanticDb, file: FileId) -> QueryResult<Option<Module>> {
+    let jar: &SemanticJar = db.jar()?;
     let modules = &jar.module_resolver;
 
     if let Some(existing) = modules.by_file.get(&file) {
@@ -343,12 +350,12 @@ where
 
     // Resolve the module name to see if Python would resolve the name to the same path.
     // If it doesn't, then that means that multiple modules have the same in different
-    // root paths, but that the module corresponding to the past path is in a lower priority path,
+    // root paths, but that the module corresponding to the past path is in a lower priority search path,
     // in which case we ignore it.
-    let Some(module_id) = resolve_module(db, module_name)? else {
+    let Some(module) = resolve_module(db, module_name)? else {
         return Ok(None);
     };
-    let module_path = module_id.path(db)?;
+    let module_path = module.path(db)?;
 
     if module_path.root() == &root_path {
         let Ok(normalized) = path.canonicalize() else {
@@ -368,7 +375,7 @@ where
         }
 
         // Path has been inserted by `resolved`
-        Ok(Some(module_id))
+        Ok(Some(module))
     } else {
         // This path is for a module with the same name but in a module search path with a lower priority.
         // Ignore it.
@@ -381,31 +388,28 @@ where
 //////////////////////////////////////////////////////
 
 /// Changes the module search paths to `search_paths`.
-pub fn set_module_search_paths<Db>(db: &mut Db, search_paths: Vec<ModuleSearchPath>)
-where
-    Db: SemanticDb + HasJar<SemanticJar>,
-{
-    let jar = db.jar_mut();
+pub fn set_module_search_paths(db: &mut dyn SemanticDb, search_paths: Vec<ModuleSearchPath>) {
+    let jar: &mut SemanticJar = db.jar_mut();
 
     jar.module_resolver = ModuleResolver::new(search_paths);
 }
 
-/// Adds a module to the resolver.
+/// Adds a module located at `path` to the resolver.
 ///
 /// Returns `None` if the path doesn't resolve to a module.
 ///
-/// Returns `Some` with the id of the module and the ids of the modules that need re-resolving
-/// because they were part of a namespace package and might now resolve differently.
+/// Returns `Some(module, other_modules)`, where `module` is the resolved module
+/// with file location `path`, and `other_modules` is a `Vec` of `ModuleData` instances.
+/// Each element in `other_modules` provides information regarding a single module that needs
+/// re-resolving because it was part of a namespace package and might now resolve differently.
+///
 /// Note: This won't work with salsa because `Path` is not an ingredient.
-pub fn add_module<Db>(db: &mut Db, path: &Path) -> Option<(Module, Vec<Arc<ModuleData>>)>
-where
-    Db: SemanticDb + HasJar<SemanticJar>,
-{
+pub fn add_module(db: &mut dyn SemanticDb, path: &Path) -> Option<(Module, Vec<Arc<ModuleData>>)> {
     // No locking is required because we're holding a mutable reference to `modules`.
 
     // TODO This needs tests
 
-    // Note: Intentionally by-pass caching here. Module should not be in the cache yet.
+    // Note: Intentionally bypass caching here. Module should not be in the cache yet.
     let module = path_to_module(db, path).ok()??;
 
     // The code below is to handle the addition of `__init__.py` files.
@@ -426,18 +430,18 @@ where
 
     let mut to_remove = Vec::new();
 
-    let jar = db.jar_mut();
+    let jar: &mut SemanticJar = db.jar_mut();
     let modules = &mut jar.module_resolver;
 
-    modules.by_file.retain(|_, id| {
+    modules.by_file.retain(|_, module| {
         if modules
             .modules
-            .get(id)
+            .get(module)
             .unwrap()
             .name
             .starts_with(&parent_name)
         {
-            to_remove.push(*id);
+            to_remove.push(*module);
             false
         } else {
             true
@@ -446,8 +450,8 @@ where
 
     // TODO remove need for this vec
     let mut removed = Vec::with_capacity(to_remove.len());
-    for id in &to_remove {
-        removed.push(modules.remove_module_by_id(*id));
+    for module in &to_remove {
+        removed.push(modules.remove_module(*module));
     }
 
     Some((module, removed))
@@ -460,10 +464,10 @@ pub struct ModuleResolver {
 
     // Locking: Locking is done by acquiring a (write) lock on `by_name`. This is because `by_name` is the primary
     // lookup method. Acquiring locks in any other ordering can result in deadlocks.
-    /// Resolves a module name to it's module id.
+    /// Looks up a module by name
     by_name: FxDashMap<ModuleName, Module>,
 
-    /// All known modules, indexed by the module id.
+    /// A map of all known modules to data about those modules
     modules: FxDashMap<Module, Arc<ModuleData>>,
 
     /// Lookup from absolute path to module.
@@ -483,24 +487,27 @@ impl ModuleResolver {
         }
     }
 
-    pub(crate) fn remove_module(&mut self, file_id: FileId) {
+    /// Remove a module from the inner cache
+    pub(crate) fn remove_module_by_file(&mut self, file_id: FileId) {
         // No locking is required because we're holding a mutable reference to `self`.
-        let Some((_, id)) = self.by_file.remove(&file_id) else {
+        let Some((_, module)) = self.by_file.remove(&file_id) else {
             return;
         };
 
-        self.remove_module_by_id(id);
+        self.remove_module(module);
     }
 
-    fn remove_module_by_id(&mut self, id: Module) -> Arc<ModuleData> {
-        let (_, module) = self.modules.remove(&id).unwrap();
+    fn remove_module(&mut self, module: Module) -> Arc<ModuleData> {
+        let (_, module_data) = self.modules.remove(&module).unwrap();
 
-        self.by_name.remove(&module.name).unwrap();
+        self.by_name.remove(&module_data.name).unwrap();
 
-        // It's possible that multiple paths map to the same id. Search all other paths referencing the same module id.
-        self.by_file.retain(|_, current_id| *current_id != id);
+        // It's possible that multiple paths map to the same module.
+        // Search all other paths referencing the same module.
+        self.by_file
+            .retain(|_, current_module| *current_module != module);
 
-        module
+        module_data
     }
 }
 
@@ -529,15 +536,19 @@ impl ModulePath {
         Self { root, file_id }
     }
 
+    /// The search path that was used to locate the module
     pub fn root(&self) -> &ModuleSearchPath {
         &self.root
     }
 
+    /// The file containing the source code for the module
     pub fn file(&self) -> FileId {
         self.file_id
     }
 }
 
+/// Given a module name and a list of search paths in which to lookup modules,
+/// attempt to resolve the module name
 fn resolve_name(
     name: &ModuleName,
     search_paths: &[ModuleSearchPath],
@@ -659,7 +670,9 @@ enum PackageKind {
     /// A root package or module. E.g. `foo` in `foo.bar.baz` or just `foo`.
     Root,
 
-    /// A regular sub-package where the parent contains an `__init__.py`. For example `bar` in `foo.bar` when the `foo` directory contains an `__init__.py`.
+    /// A regular sub-package where the parent contains an `__init__.py`.
+    ///
+    /// For example, `bar` in `foo.bar` when the `foo` directory contains an `__init__.py`.
     Regular,
 
     /// A sub-package in a namespace package. A namespace package is a package without an `__init__.py`.
@@ -676,12 +689,16 @@ impl PackageKind {
 
 #[cfg(test)]
 mod tests {
-    use crate::db::tests::TestDb;
-    use crate::db::{SemanticDb, SourceDb};
-    use crate::module::{ModuleKind, ModuleName, ModuleSearchPath, ModuleSearchPathKind};
-    use crate::symbols::Dependency;
     use std::num::NonZeroU32;
 
+    use crate::db::tests::TestDb;
+    use crate::db::SourceDb;
+    use crate::module::{
+        path_to_module, resolve_module, set_module_search_paths, ModuleKind, ModuleName,
+        ModuleSearchPath, ModuleSearchPathKind,
+    };
+    use crate::semantic::Dependency;
+
     struct TestCase {
         temp_dir: tempfile::TempDir,
         db: TestDb,
@@ -708,7 +725,7 @@ mod tests {
         let roots = vec![src.clone(), site_packages.clone()];
 
         let mut db = TestDb::default();
-        db.set_module_search_paths(roots);
+        set_module_search_paths(&mut db, roots);
 
         Ok(TestCase {
             temp_dir,
@@ -730,16 +747,19 @@ mod tests {
         let foo_path = src.path().join("foo.py");
         std::fs::write(&foo_path, "print('Hello, world!')")?;
 
-        let foo_module = db.resolve_module(ModuleName::new("foo"))?.unwrap();
+        let foo_module = resolve_module(&db, ModuleName::new("foo"))?.unwrap();
 
-        assert_eq!(Some(foo_module), db.resolve_module(ModuleName::new("foo"))?);
+        assert_eq!(
+            Some(foo_module),
+            resolve_module(&db, ModuleName::new("foo"))?
+        );
 
         assert_eq!(ModuleName::new("foo"), foo_module.name(&db)?);
         assert_eq!(&src, foo_module.path(&db)?.root());
         assert_eq!(ModuleKind::Module, foo_module.kind(&db)?);
         assert_eq!(&foo_path, &*db.file_path(foo_module.path(&db)?.file()));
 
-        assert_eq!(Some(foo_module), db.path_to_module(&foo_path)?);
+        assert_eq!(Some(foo_module), path_to_module(&db, &foo_path)?);
 
         Ok(())
     }
@@ -758,16 +778,16 @@ mod tests {
         std::fs::create_dir(&foo_dir)?;
         std::fs::write(&foo_path, "print('Hello, world!')")?;
 
-        let foo_module = db.resolve_module(ModuleName::new("foo"))?.unwrap();
+        let foo_module = resolve_module(&db, ModuleName::new("foo"))?.unwrap();
 
         assert_eq!(ModuleName::new("foo"), foo_module.name(&db)?);
         assert_eq!(&src, foo_module.path(&db)?.root());
         assert_eq!(&foo_path, &*db.file_path(foo_module.path(&db)?.file()));
 
-        assert_eq!(Some(foo_module), db.path_to_module(&foo_path)?);
+        assert_eq!(Some(foo_module), path_to_module(&db, &foo_path)?);
 
         // Resolving by directory doesn't resolve to the init file.
-        assert_eq!(None, db.path_to_module(&foo_dir)?);
+        assert_eq!(None, path_to_module(&db, &foo_dir)?);
 
         Ok(())
     }
@@ -789,14 +809,14 @@ mod tests {
         let foo_py = src.path().join("foo.py");
         std::fs::write(&foo_py, "print('Hello, world!')")?;
 
-        let foo_module = db.resolve_module(ModuleName::new("foo"))?.unwrap();
+        let foo_module = resolve_module(&db, ModuleName::new("foo"))?.unwrap();
 
         assert_eq!(&src, foo_module.path(&db)?.root());
         assert_eq!(&foo_init, &*db.file_path(foo_module.path(&db)?.file()));
         assert_eq!(ModuleKind::Package, foo_module.kind(&db)?);
 
-        assert_eq!(Some(foo_module), db.path_to_module(&foo_init)?);
-        assert_eq!(None, db.path_to_module(&foo_py)?);
+        assert_eq!(Some(foo_module), path_to_module(&db, &foo_init)?);
+        assert_eq!(None, path_to_module(&db, &foo_py)?);
 
         Ok(())
     }
@@ -815,13 +835,13 @@ mod tests {
         std::fs::write(&foo_stub, "x: int")?;
         std::fs::write(&foo_py, "print('Hello, world!')")?;
 
-        let foo = db.resolve_module(ModuleName::new("foo"))?.unwrap();
+        let foo = resolve_module(&db, ModuleName::new("foo"))?.unwrap();
 
         assert_eq!(&src, foo.path(&db)?.root());
         assert_eq!(&foo_stub, &*db.file_path(foo.path(&db)?.file()));
 
-        assert_eq!(Some(foo), db.path_to_module(&foo_stub)?);
-        assert_eq!(None, db.path_to_module(&foo_py)?);
+        assert_eq!(Some(foo), path_to_module(&db, &foo_stub)?);
+        assert_eq!(None, path_to_module(&db, &foo_py)?);
 
         Ok(())
     }
@@ -844,12 +864,12 @@ mod tests {
         std::fs::write(bar.join("__init__.py"), "")?;
         std::fs::write(&baz, "print('Hello, world!')")?;
 
-        let baz_module = db.resolve_module(ModuleName::new("foo.bar.baz"))?.unwrap();
+        let baz_module = resolve_module(&db, ModuleName::new("foo.bar.baz"))?.unwrap();
 
         assert_eq!(&src, baz_module.path(&db)?.root());
         assert_eq!(&baz, &*db.file_path(baz_module.path(&db)?.file()));
 
-        assert_eq!(Some(baz_module), db.path_to_module(&baz)?);
+        assert_eq!(Some(baz_module), path_to_module(&db, &baz)?);
 
         Ok(())
     }
@@ -890,16 +910,12 @@ mod tests {
         std::fs::create_dir_all(&child2)?;
         std::fs::write(&two, "print('Hello, world!')")?;
 
-        let one_module = db
-            .resolve_module(ModuleName::new("parent.child.one"))?
-            .unwrap();
+        let one_module = resolve_module(&db, ModuleName::new("parent.child.one"))?.unwrap();
 
-        assert_eq!(Some(one_module), db.path_to_module(&one)?);
+        assert_eq!(Some(one_module), path_to_module(&db, &one)?);
 
-        let two_module = db
-            .resolve_module(ModuleName::new("parent.child.two"))?
-            .unwrap();
-        assert_eq!(Some(two_module), db.path_to_module(&two)?);
+        let two_module = resolve_module(&db, ModuleName::new("parent.child.two"))?.unwrap();
+        assert_eq!(Some(two_module), path_to_module(&db, &two)?);
 
         Ok(())
     }
@@ -941,15 +957,13 @@ mod tests {
         std::fs::create_dir_all(&child2)?;
         std::fs::write(two, "print('Hello, world!')")?;
 
-        let one_module = db
-            .resolve_module(ModuleName::new("parent.child.one"))?
-            .unwrap();
+        let one_module = resolve_module(&db, ModuleName::new("parent.child.one"))?.unwrap();
 
-        assert_eq!(Some(one_module), db.path_to_module(&one)?);
+        assert_eq!(Some(one_module), path_to_module(&db, &one)?);
 
         assert_eq!(
             None,
-            db.resolve_module(ModuleName::new("parent.child.two"))?
+            resolve_module(&db, ModuleName::new("parent.child.two"))?
         );
         Ok(())
     }
@@ -969,13 +983,13 @@ mod tests {
         std::fs::write(&foo_src, "")?;
         std::fs::write(&foo_site_packages, "")?;
 
-        let foo_module = db.resolve_module(ModuleName::new("foo"))?.unwrap();
+        let foo_module = resolve_module(&db, ModuleName::new("foo"))?.unwrap();
 
         assert_eq!(&src, foo_module.path(&db)?.root());
         assert_eq!(&foo_src, &*db.file_path(foo_module.path(&db)?.file()));
 
-        assert_eq!(Some(foo_module), db.path_to_module(&foo_src)?);
-        assert_eq!(None, db.path_to_module(&foo_site_packages)?);
+        assert_eq!(Some(foo_module), path_to_module(&db, &foo_src)?);
+        assert_eq!(None, path_to_module(&db, &foo_site_packages)?);
 
         Ok(())
     }
@@ -996,8 +1010,8 @@ mod tests {
         std::fs::write(&foo, "")?;
         std::os::unix::fs::symlink(&foo, &bar)?;
 
-        let foo_module = db.resolve_module(ModuleName::new("foo"))?.unwrap();
-        let bar_module = db.resolve_module(ModuleName::new("bar"))?.unwrap();
+        let foo_module = resolve_module(&db, ModuleName::new("foo"))?.unwrap();
+        let bar_module = resolve_module(&db, ModuleName::new("bar"))?.unwrap();
 
         assert_ne!(foo_module, bar_module);
 
@@ -1010,8 +1024,8 @@ mod tests {
         assert_eq!(foo_module.path(&db)?.file(), bar_module.path(&db)?.file());
         assert_eq!(&foo, &*db.file_path(bar_module.path(&db)?.file()));
 
-        assert_eq!(Some(foo_module), db.path_to_module(&foo)?);
-        assert_eq!(Some(bar_module), db.path_to_module(&bar)?);
+        assert_eq!(Some(foo_module), path_to_module(&db, &foo)?);
+        assert_eq!(Some(bar_module), path_to_module(&db, &bar)?);
 
         Ok(())
     }
@@ -1033,8 +1047,8 @@ mod tests {
         std::fs::write(foo_path, "from .bar import test")?;
         std::fs::write(bar_path, "test = 'Hello world'")?;
 
-        let foo_module = db.resolve_module(ModuleName::new("foo"))?.unwrap();
-        let bar_module = db.resolve_module(ModuleName::new("foo.bar"))?.unwrap();
+        let foo_module = resolve_module(&db, ModuleName::new("foo"))?.unwrap();
+        let bar_module = resolve_module(&db, ModuleName::new("foo.bar"))?.unwrap();
 
         // `from . import bar` in `foo/__init__.py` resolves to `foo`
         assert_eq!(
