@@ -28,6 +28,7 @@ pub(crate) struct RuffSettings {
 }
 
 pub(super) struct RuffSettingsIndex {
+    /// Index from folder to the resoled ruff settings.
     index: BTreeMap<PathBuf, Arc<RuffSettings>>,
     fallback: Arc<RuffSettings>,
 }
@@ -73,10 +74,17 @@ impl RuffSettings {
         }
     }
 
+    /// Return the [`ruff_workspace::FileResolverSettings`] for this [`RuffSettings`].
+    pub(crate) fn file_resolver(&self) -> &ruff_workspace::FileResolverSettings {
+        &self.file_resolver
+    }
+
+    /// Return the [`ruff_linter::settings::LinterSettings`] for this [`RuffSettings`].
     pub(crate) fn linter(&self) -> &ruff_linter::settings::LinterSettings {
         &self.linter
     }
 
+    /// Return the [`ruff_workspace::FormatterSettings`] for this [`RuffSettings`].
     pub(crate) fn formatter(&self) -> &ruff_workspace::FormatterSettings {
         &self.formatter
     }
@@ -182,14 +190,15 @@ impl RuffSettingsIndex {
     }
 
     pub(super) fn get(&self, document_path: &Path) -> Arc<RuffSettings> {
-        if let Some((_, settings)) = self
-            .index
+        self.index
             .range(..document_path.to_path_buf())
             .rfind(|(path, _)| document_path.starts_with(path))
-        {
-            return settings.clone();
-        }
+            .map(|(_, settings)| settings)
+            .unwrap_or_else(|| &self.fallback)
+            .clone()
+    }
 
+    pub(super) fn fallback(&self) -> Arc<RuffSettings> {
         self.fallback.clone()
     }
 }
